==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/newthread.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright © 2008 MyBB Group, All Rights Reserved
 * 
 * $Id: newthread.lang.php 4304 2009-01-02 01:11:56Z chris $
 */

$l['nav_newthread'] = "New Thread";
$l['newthread_in'] = "New Thread in {1}";
$l['post_new_thread'] = "Post a new Thread";
$l['thread_subject'] = "Thread Subject";
$l['your_message'] = "Your Message:";
$l['post_options'] = "Post Options:";
$l['options_sig'] = "<b>Signature:</b> include your signature. (registered users only)";
$l['options_emailnotify'] = "<b>Email Notification:</b> receive an email whenever there is a new reply. (registered users only)";
$l['options_disablesmilies'] = "<b>Disable Smilies:</b> disable smilies from showing in this post.";
$l['post_thread'] = "Post Thread";
$l['preview_post'] = "Preview Post";
$l['poll'] = "Poll:";
$l['poll_desc'] = "Optionally you may attach a poll to this thread.";
$l['poll_check'] = "I want to post a poll";
$l['num_options'] = "Number of options:";
$l['max_options'] = "(Maximum: {1})";
$l['mod_options'] ="Moderator Options:";
$l['close_thread'] = "<b>Close Thread</b>: prevent further posting in this thread.";
$l['stick_thread'] = "<b>Stick Thread:</b> stick this thread to the top of the forum.";
$l['draft_saved'] = "The new thread has successfully been saved as a draft.<br />You will now be taken to your draft listing.";
$l['image_verification'] = "Image Verification";
$l['verification_note'] = "Please enter the text within the image on the left in to the text box below. This process is used to prevent automated posts.";
$l['verification_subnote'] = "(case insensitive)";
$l['invalid_captcha'] = "The image verification code that you entered was incorrect. Please enter the code exactly how it appears in the image.";
$l['error_post_already_submitted'] = "You have already posted this thread in this forum. Please visit the forum to see your thread.";

$l['multiquote_external_one'] = "You have selected one post from another thread.";
$l['multiquote_external'] = "You have selected {1} posts from other threads.";
$l['multiquote_external_one_deselect'] = "deselect this post";
$l['multiquote_external_deselect'] = "deselect these posts";
$l['multiquote_external_one_quote'] = "Quote this post too";
$l['multiquote_external_quote'] = "Quote these posts too";

$l['redirect_newthread'] = "Thank you, your thread has been posted."; 
$l['redirect_newthread_poll'] = "<br />You will now be taken to the poll options and configuration page."; 
$l['redirect_newthread_moderation'] = "<br />The administrator has specified that all new threads require moderation. You will now be returned to the thread listing."; 
$l['redirect_newthread_thread'] = "<br />You will now be taken to the new thread.";
?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/newthread.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 * 
 * $Id: newthread.lang.php 5617 2011-09-20 13:50:05Z Tomm $
 */

$l['nav_newthread'] = "New Thread";
$l['newthread_in'] = "New Thread in {1}";
$l['post_new_thread'] = "Post a new Thread";
$l['thread_subject'] = "Thread Subject";
$l['your_message'] = "Your Message:";
$l['post_options'] = "Post Options:";
$l['options_sig'] = "<b>Signature:</b> include your signature. (registered users only)";
$l['options_emailnotify'] = "<b>Email Notification:</b> receive an email whenever there is a new reply. (registered users only)";
$l['options_disablesmilies'] = "<b>Disable Smilies:</b> disable smilies from showing in this post.";
$l['post_thread'] = "Post Thread";
$l['preview_post'] = "Preview Post";
$l['poll'] = "Poll:";
$l['poll_desc'] = "Optionally you may attach a poll to this thread.";
$l['poll_check'] = "I want to post a poll";
$l['num_options'] = "Number of options:";
$l['max_options'] = "(Maximum: {1})";
$l['mod_options'] ="Moderator Options:";
$l['close_thread'] = "<b>Close Thread</b>: prevent further posting in this thread.";
$l['stick_thread'] = "<b>Stick Thread:</b> stick this thread to the top of the forum.";
$l['draft_saved'] = "The new thread has successfully been saved as a draft.<br />You will now be taken to your draft listing.";
$l['image_verification'] = "Image Verification";
$l['verification_note'] = "Please enter the text contained within the image into the text box below it. This process is used to prevent automated posts.";
$l['verification_subnote'] = "(case insensitive)";
$l['invalid_captcha'] = "The image verification code that you entered was incorrect. Please enter the code exactly how it appears in the image.";
$l['error_post_already_submitted'] = "You have already posted this thread in this forum. Please visit the forum to see your thread.";
$l['no_prefix'] = "No Prefix";

$l['multiquote_external_one'] = "You have selected one post from another thread.";
$l['multiquote_external'] = "You have selected {1} posts from other threads.";
$l['multiquote_external_one_deselect'] = "deselect this post";
$l['multiquote_external_deselect'] = "deselect these posts";
$l['multiquote_external_one_quote'] = "Quote this post too";
$l['multiquote_external_quote'] = "Quote these posts too";

$l['redirect_newthread'] = "Thank you, your thread has been posted."; 
$l['redirect_newthread_poll'] = "<br />You will now be taken to the poll options and configuration page."; 
$l['redirect_newthread_moderation'] = "<br />The administrator has specified that all new threads require moderation. You will now be returned to the thread listing."; 
$l['redirect_newthread_thread'] = "<br />You will now be taken to the new thread.";
$l['invalidthread'] = "The specified draft does not exist or you don't have permission to view it.";
?>
